@@ -9,13 +9,14 @@
 #include "libbcachefs.h"
 #include "tools-util.h"
 
-#include "libbcachefs/bcachefs.h"
-#include "libbcachefs/btree_iter.h"
-#include "libbcachefs/errcode.h"
-#include "libbcachefs/error.h"
-#include "libbcachefs/journal_io.h"
-#include "libbcachefs/journal_seq_blacklist.h"
-#include "libbcachefs/super.h"
+#include "bcachefs.h"
+#include "btree/iter.h"
+
+#include "init/error.h"
+#include "init/fs.h"
+
+#include "journal/read.h"
+#include "journal/seq_blacklist.h"
 
 #include <linux/fs_parser.h>
 
@@ -439,6 +440,7 @@ static void list_journal_usage(void)
 	     "                                   Or entries not matching the range bbpos-bbpos\n"
 	     "  -v, --verbose                    Verbose mode\n"
 	     "  -h, --help                       Display this help and exit\n"
+	     "\n"
 	     "Report bugs to <linux-bcachefs@vger.kernel.org>");
 }
 
